@@ -478,7 +478,25 @@ def main(  # pylint: disable=too-many-arguments
     return gen
 
 
-@click.group(chain=True, invoke_without_command=True, context_settings=CONTEXT_SETTINGS)
+class AliasedGroup(click.Group):
+    def get_command(self, ctx, cmd_name):
+        rv = click.Group.get_command(self, ctx, cmd_name)
+        if rv is not None:
+            return rv
+        matches = [x for x in self.list_commands(ctx) if x.startswith(cmd_name)]
+        if not matches:
+            return None
+        elif len(matches) == 1:
+            return click.Group.get_command(self, ctx, matches[0])
+        ctx.fail("Too many matches: %s" % ", ".join(sorted(matches)))
+
+
+@click.group(
+    chain=True,
+    invoke_without_command=True,
+    context_settings=CONTEXT_SETTINGS,
+    cls=AliasedGroup,
+)
 @click.option(
     "--newlines",
     "-n",
@@ -546,11 +564,18 @@ def str_to_bool(string, strict=False):
 @cli.resultcallback()
 def process_pipeline(processors, **kwargs):
 
+
     if kwargs["version"]:
         print(f"{pype.__name__} {pype._version.__version__}")
         return
 
-    if kwargs["do_eval"]:
+    # TODO Test that eval runs without stdin content.
+    try:
+        is_eval = processors[0].is_eval
+    except AttributeError:
+        is_eval = False
+
+    if kwargs["do_eval"] or is_eval:
         in_stream = "\n"
     else:
         in_stream = click.get_text_stream("stdin")
@@ -562,8 +587,8 @@ def process_pipeline(processors, **kwargs):
     if kwargs["do_async"]:
         options["reactor"] = twisted.internet.reactor
 
-    # if kwargs["do_async"] and len(processors) > 1:
-    #     raise PypeException("Async multi-stage pipeline not implemented.")
+    if kwargs["do_async"] and len(processors) > 1:
+        raise PypeException("Async multi-stage pipeline not implemented.")
 
     input_has_newlines, items = _has_newlines(in_stream)
     for processor in processors:
@@ -621,6 +646,7 @@ def cli_eval(expression):
     def wrapped(do_eval, in_stream, **kwargs):
         return main(mapper=expression, do_eval=True, in_stream="\n", **kwargs)
 
+    wrapped.is_eval = True
     return wrapped
 
 
